''' "grove": [{ # # The essential nutrient from the # essential nutrient grove DB. # "info": { "names": [ "vitamin b", "cobalamin" ], "includes": [] }, # # The ingredient from either: # # USDA: # foodNutrients (flat list) # # NIH: # ingredientRows (tree) # nestedRows # nestedRows # "natures": [{ "identity": { "name": "", "UPC": "", "DSLD ID": "", "FDC ID": "" } }], "unites": [{ "info": {}, "ingredients": [], "unites": [] }] }] '''